@@ -1913,3 +1913,56 @@ def set_ticks(axis, ticks, labels=None, minor=False):
     """
     ax = get_axis()
     return ax.set_ticks(axis, ticks, labels, minor)
+
+
+def create_mappable(vmin, vmax, cmap, log=False):
+    """
+    Create a ScalarMappable, which is used to get colors from a colorbar
+
+    This is also often used to seed a colorbar.
+
+    :param vmin: Value corresponding to the minimum value of the colormap
+    :type vmin: float
+    :param vmax: Value corresponding to the maximum value of the colormap
+    :type vmax: float
+    :param cmap: The colormap to use. Can be a string with the colormap name
+             or a colormap object
+    :param log: Whether or not to use log scaling on the normalization between
+            vmin and vmax
+    :type log: bool
+    :returns: The ScalarMappable object
+    :rtype: matplotlib.cm.ScalarMappable
+
+    .. plot::
+        :include-source:
+
+        import betterplotlib as bpl
+        import numpy as np
+
+        bpl.set_style()
+
+        mappable = bpl.create_mappable(0, 1, "Blues")
+        fig, ax = bpl.subplots()
+        for i in np.arange(0, 1.01, 0.1):
+        ax.plot([0, 1], [i, i], c=mappable.to_rgba(i))
+        ax.set_limits(0, 1, -0.05, 1.05)
+        fig.colorbar(mappable)
+
+    .. plot::
+        :include-source:
+
+        import betterplotlib as bpl
+        import numpy as np
+
+        bpl.set_style()
+
+        mappable = bpl.create_mappable(1, 100, "Blues", log=True)
+        fig, ax = bpl.subplots()
+        for i in np.logspace(0, 2, 10):
+        ax.plot([0, 1], [i, i], c=mappable.to_rgba(i))
+        ax.log("y")
+        ax.set_limits(0, 1, 0.9, 110)
+        fig.colorbar(mappable)
+    """
+    ax = get_axis()
+    return ax.create_mappable(vmin, vmax, cmap, log)
